@@ -16,7 +16,6 @@ __date__ = '2018-07-18'
 import argparse
 import gc
 import itertools
-import logging
 import os
 import tempfile
 import time
@@ -27,18 +26,20 @@ from multiprocessing import cpu_count
 import numpy as np
 from ase.data import atomic_numbers
 from ase.io import write as write_xyz
-from pkg_resources import DistributionNotFound, get_distribution
 from sklearn import preprocessing
 from sklearn.cluster import MiniBatchKMeans
 
+from ._logger import logger
 from .detect import Detect
-from .utils import run_mp, bytestolist, listtobytes, must_be_list, _mkdir
+from .utils import (
+    run_mp,
+    bytestolist,
+    listtobytes,
+    read_compressed_block,
+    must_be_list,
+)
 
-try:
-    __version__ = get_distribution(__name__).version
-except DistributionNotFound:
-    # package is not installed
-    __version__ = ''
+from ._version import version as __version__
 
 
 class DatasetBuilder:
@@ -144,20 +145,20 @@ class DatasetBuilder:
                             self._writecoulumbmatrix(bondtype, f)
                             gc.collect()
                 elif runstep == 2:
-                    _mkdir(self.dataset_dir)
+                    os.makedirs(self.dataset_dir, exist_ok=True)
                     if self.writegjf:
-                        _mkdir(self.gjfdir)
+                        os.makedirs(self.gjfdir, exist_ok=True)
                     self._writexyzfiles()
                 gc.collect()
                 timearray.append(time.time())
-                logging.info(
+                logger.info(
                     f"Step {len(timearray)-1} Done! Time consumed (s): {timearray[-1]-timearray[-2]:.3f}")
 
     def _readtimestepsbond(self):
         """Read and store the bond of each atom in each frame."""
         # added on 2018-12-15
         stepatomfiles = {}
-        _mkdir(self.trajatom_dir)
+        os.makedirs(self.trajatom_dir, exist_ok=True)
         results = run_mp(self.nproc, func=self.bonddetector.readatombondtype,
                          l=zip(self.lineiter(self.bonddetector), self.erroriter(
                          )) if self.errorfilename is not None else self.lineiter(self.bonddetector),
@@ -190,7 +191,7 @@ class DatasetBuilder:
         """
         self.dstep = {}
         with open(os.path.join(self.trajatom_dir, f"stepatom.{trajatomfilename}"), 'rb') as f:
-            for line in f:
+            for line in read_compressed_block(f):
                 s = bytestolist(line)
                 self.dstep[s[0]] = s[1]
         n_atoms = sum(map(len, self.dstep.values()))
@@ -221,7 +222,7 @@ class DatasetBuilder:
                         lambda x:vector_elements[x[0]][: x[1]], symbols_counter.items()), [])]=vector
                     max_counter |= symbols_counter
                     j += 1
-            logging.info(
+            logger.info(
                 f"Max counter of {trajatomfilename} is {max_counter}")
             choosedindexs = self._clusterdatas(
                 np.sort(feedvector), n_clusters=self.n_clusters,
@@ -346,7 +347,7 @@ class DatasetBuilder:
         self.dstep = defaultdict(list)
         with open(os.path.join(self.trajatom_dir, "chooseatoms"), 'rb') as fc:
             typecounter = Counter()
-            for typefile, trajatomfilename in zip(fc, self.atombondtype):
+            for typefile, trajatomfilename in zip(read_compressed_block(fc), self.atombondtype):
                 for step, atoma in bytestolist(typefile):
                     self.dstep[step].append(
                         (atoma, trajatomfilename,
@@ -360,10 +361,10 @@ class DatasetBuilder:
             foldernames = list(map(lambda i: str(i).zfill(
                 self.foldermaxlength), range(foldernum)))
             for folder in foldernames:
-                _mkdir(os.path.join(self.dataset_dir, folder))
+                os.makedirs(os.path.join(self.dataset_dir, folder), exist_ok=True)
             if self.writegjf:
                 for folder in foldernames:
-                    _mkdir(os.path.join(self.gjfdir, folder))
+                    os.makedirs(os.path.join(self.gjfdir, folder), exist_ok=True)
             crditer = self.lineiter(self.crddetector)
             if self.crddetector is self.bonddetector:
                 lineiter = crditer
